searchData={"items":[{"type":"module","title":"KinoLiveView","doc":"Documentation for `KinoLiveView`.","ref":"KinoLiveView.html"},{"type":"function","title":"KinoLiveView.get_routes/0","doc":"Get the routes defined by KinoLiveView.SmartCell from within Livebook.","ref":"KinoLiveView.html#get_routes/0"},{"type":"function","title":"Examples - KinoLiveView.get_routes/0","doc":"You can use `KinoLiveView.get_routes/0` to dynamically inject routes in your Phoenix router.ex file.\n\n    ```elixir\n    # router.ex\n    if Application.compile_env(:kino_live_view, :enabled) do\n      scope \"/\" do\n        pipe_through :browser\n\n        KinoLiveView.get_routes()\n        |> Enum.map(fn %{path: path, module: module, action: action} ->\n          live(path, module, action)\n        end)\n      end\n    end\n    ```","ref":"KinoLiveView.html#get_routes/0-examples"},{"type":"module","title":"KinoLiveView.LiveReloader","doc":"","ref":"KinoLiveView.LiveReloader.html"},{"type":"function","title":"KinoLiveView.LiveReloader.reload/0","doc":"","ref":"KinoLiveView.LiveReloader.html#reload/0"},{"type":"module","title":"KinoLiveView.LiveReloader.Channel","doc":"The client listens on the phoenix:live_reload channel for the \"assets_change\" message.\nSo we send \"assets_change\" js event, the client will reload the page.\n\nFurther explanation here: https://shankardevy.com/code/phoenix-live-reload/","ref":"KinoLiveView.LiveReloader.Channel.html"},{"type":"function","title":"KinoLiveView.LiveReloader.Channel.child_spec/1","doc":"","ref":"KinoLiveView.LiveReloader.Channel.html#child_spec/1"},{"type":"function","title":"KinoLiveView.LiveReloader.Channel.handle_info/2","doc":"","ref":"KinoLiveView.LiveReloader.Channel.html#handle_info/2"},{"type":"function","title":"KinoLiveView.LiveReloader.Channel.join/3","doc":"","ref":"KinoLiveView.LiveReloader.Channel.html#join/3"},{"type":"function","title":"KinoLiveView.LiveReloader.Channel.start_link/1","doc":"","ref":"KinoLiveView.LiveReloader.Channel.html#start_link/1"},{"type":"module","title":"KinoLiveView.LiveReloader.Socket","doc":"","ref":"KinoLiveView.LiveReloader.Socket.html"},{"type":"function","title":"KinoLiveView.LiveReloader.Socket.connect/2","doc":"","ref":"KinoLiveView.LiveReloader.Socket.html#connect/2"},{"type":"function","title":"KinoLiveView.LiveReloader.Socket.id/1","doc":"","ref":"KinoLiveView.LiveReloader.Socket.html#id/1"},{"type":"module","title":"KinoLiveView.SmartCell","doc":"","ref":"KinoLiveView.SmartCell.html"},{"type":"function","title":"KinoLiveView.SmartCell.child_spec/1","doc":"","ref":"KinoLiveView.SmartCell.html#child_spec/1"},{"type":"macro","title":"KinoLiveView.SmartCell.defmodule/2","doc":"","ref":"KinoLiveView.SmartCell.html#defmodule/2"},{"type":"function","title":"KinoLiveView.SmartCell.get_routes/0","doc":"","ref":"KinoLiveView.SmartCell.html#get_routes/0"},{"type":"function","title":"KinoLiveView.SmartCell.put_routes/1","doc":"","ref":"KinoLiveView.SmartCell.html#put_routes/1"},{"type":"function","title":"KinoLiveView.SmartCell.register/2","doc":"","ref":"KinoLiveView.SmartCell.html#register/2"},{"type":"extras","title":"KinoLiveView","doc":"# KinoLiveView\n\n[![Hex.pm](https://img.shields.io/hexpm/v/kino_live_view.svg)](https://hex.pm/packages/kino_live_view) [![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/kino_live_view/0.1.0/readme.html)\n\nKinoLiveView lets you dynamically create LiveViews for your Phoenix Application from within a Livebook.\n\nThis project is experimental.","ref":"readme.html"},{"type":"extras","title":"Installation - KinoLiveView","doc":"Add `kino_live_view` to your list of dependencies in `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:kino_live_view, \"~> 0.1.0\", only: :dev}\n  ]\nend\n```\n\nConfigure `kino_live_view` in `dev.exs`. Replace `MyApp` with your application name.\n\n```elixir\nconfig :kino_live_view,\n  enabled: true,\n  pubsub_server: MyApp.PubSub,\n  router_module: MyAppWeb.Router,\n  socket: KinoLiveView.LiveReloader.Socket\n```\n\nUse the `KinoLiveView.LiveReloader.Socket` in `endpoint.ex` to allow the `KinoLiveView` project to trigger code reloading.\n\n```elixir\nif code_reloading? do\n  # Swap the socket from Phoenix.LiveReloader.Socket to KinoLiveView.LiveReloader.Socket.\n  # This is important for hot reloaded the project when new LiveViews are injected.\n  socket \"/phoenix/live_reload/socket\", Application.get_env(:kino_live_view, :socket, Phoenix.LiveReloader.Socket)\n  plug Phoenix.LiveReloader\n  plug Phoenix.CodeReloader\n  plug Phoenix.Ecto.CheckRepoStatus, otp_app: :my_app\nend\n```\n\nDynamically inject the routes in `router.ex`.\n\n```elixir\nif Application.compile_env(:kino_live_view, :enabled) do\n  scope \"/\" do\n    pipe_through :browser\n\n    KinoLiveView.get_routes()\n    |> Enum.map(fn %{path: path, module: module, action: action} ->\n      live(path, module, action)\n    end)\n  end\nend\n```\n\nRegister the `KinoLiveView.SmartCell` in `application.ex`.\n\n```elixir\n  def start(_type, _args) do\n    children = [\n      # children should be unaffected\n      ...\n    ]\n\n    # Register the KinoLiveView.SmartCell\n    if Application.get_env(:kino_live_view, :enabled) do\n      Kino.SmartCell.register(KinoLiveView.SmartCell)\n    end\n\n    # See https://hexdocs.pm/elixir/Supervisor.html\n    # for other strategies and supported options\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\n```\n\nStart your Phoenix server with the `sname` and `cookie` flags.\n\n```sh\n$ iex --sname test --cookie mycookie -S mix phx.server\n```\n\nRun Livebook as an attached node.\n\n![Run Livebook As Attached Node](assets/images/run_as_attached_node.png)\n\nCreate a `KinoLiveView` Smart Cell in Livebook.\n\n![KinoLiveView Smart Cell](assets/images/hello_world_kino_live_smart_cell_web.png)\n\nYou should see the new LiveView page on localhost:4000 or whichever URL your server runs on.\n\nThis project is also compatible with [LiveView Native](https://github.com/liveview-native/live_view_native).\n\n![KinoLiveView Smart Cell](assets/images/hello_world_kino_live_smart_cell_native.png)","ref":"readme.html#installation"}],"content_type":"text/markdown"}